#!/usr/bin/env python

"""
Preparation of templating stylesheets.

Copyright (C) 2005 Paul Boddie <paul@boddie.org.uk>

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
"""

from XSLTools import XSLOutput
import libxml2dom
import os

resource_dir = os.path.join(os.path.split(__file__)[0], "XSL")

def make_stylesheet(template_name, output_name, stylesheet_names=["PrepareMacro.xsl", "Prepare.xsl"], encoding=None):

    """
    Make an output stylesheet using the file with the given 'template_name',
    producing a file with the given 'output_name'.
    """

    stylesheets = [os.path.join(resource_dir, stylesheet_name) for stylesheet_name in stylesheet_names]
    proc = XSLOutput.Processor(stylesheets)
    template = libxml2dom.parse(template_name)
    proc.send_output(open(output_name, "wb"), encoding, template)

def make_stylesheet_fragment(template_name, output_name, element_id, stylesheet_name="Extract.xsl", encoding=None):

    """
    Make an output stylesheet using the file with the given 'template_name',
    producing a file with the given 'output_name', capturing the fragment
    identified by the given 'element_id'.
    """

    proc = XSLOutput.Processor([os.path.join(resource_dir, stylesheet_name)], parameters={"element-id" : element_id})
    template = libxml2dom.parse(template_name)
    proc.send_output(open(output_name, "wb"), encoding, template)

def ensure_stylesheet(template_name, output_name):

    """
    Ensure the presence of an output stylesheet, preparing it if necessary
    using the file with the given 'template_name', producing a file with the
    given 'output_name'.
    """

    if not os.path.exists(output_name) or \
        os.path.getmtime(output_name) < os.path.getmtime(template_name):

        make_stylesheet(template_name, output_name)

def ensure_stylesheet_fragment(template_name, output_name, element_id):

    """
    Ensure the presence of an output stylesheet, preparing it if necessary
    using the file with the given 'template_name', producing a file with the
    given 'output_name', capturing the fragment identified by the given
    'element_id'.
    """

    if not os.path.exists(output_name) or \
        os.path.getmtime(output_name) < os.path.getmtime(template_name):

        make_stylesheet_fragment(template_name, output_name, element_id)

def make_input_stylesheet(template_name, input_name, stylesheet_names=["Schema.xsl", "Input.xsl"], encoding=None):

    """
    Make an input stylesheet using the file with the given 'template_name',
    producing a file with the given 'input_name'. Such stylesheets are used to
    ensure the general structure of an input document.
    """

    stylesheets = [os.path.join(resource_dir, stylesheet_name) for stylesheet_name in stylesheet_names]
    proc = XSLOutput.Processor(stylesheets)
    template = libxml2dom.parse(template_name)
    proc.send_output(open(input_name, "wb"), encoding, template)

def ensure_input_stylesheet(template_name, input_name):

    """
    Ensure the presence of an input stylesheet, preparing it if necessary
    using the file with the given 'template_name', producing a file with the
    given 'input_name'.
    """

    if not os.path.exists(input_name) or \
        os.path.getmtime(input_name) < os.path.getmtime(template_name):

        make_input_stylesheet(template_name, input_name)

# vim: tabstop=4 expandtab shiftwidth=4
